@@ -111,7 +111,7 @@ class Session:
         self.session_id = time.time()
         self.explicit = np.full(self.recommender.n_items, fill_value=np.nan)
         self.movie_id, self.initial_markdown, self.initial_poster_url = self.content()
-        self.content_task = asyncio.create_task(self.async_content())
+        self.content_task = self.content()
 
     def __deepcopy__(self, memo):
         """
@@ -162,8 +162,12 @@ class Session:
         )
 
     async def next_content(self, feedback: Feedback):
-        with Timer(name="await_content"):
-            next_movie_id, markdown, poster_url = await self.content_task
+        if asyncio.isfuture(self.content_task):
+            with Timer(name="await_content"):
+                content = await self.content_task
+        else:
+            content = self.content_task
+        next_movie_id, markdown, poster_url = content
         self.save_rating(rating=feedback.rating, movie_id=self.movie_id)
         wandb.log(
             dict(
